pub enum CallmError {
GenericError(String),
LoaderFail(String),
UnsupportedModel,
IOError(Error),
CandleError(Error),
TemplateError(String),
TokenizerError {
msg: String,
},
SerdeError(Error),
}Expand description
An enumeration of all possible errors.
Variants
GenericError(String)
A generic error with a custom message.
LoaderFail(String)
An error indicating a failure in the model loader with a custom message.
UnsupportedModel
An error indicating that the model is unsupported.
IOError(Error)
An error wrapping an I/O error from the standard library.
CandleError(Error)
An error wrapping a Candle error from the candle_core crate.
TemplateError(String)
An error indicating a failure in the template with a custom message.
TokenizerError
An error indicating a failure in the tokenizer with a custom message.
SerdeError(Error)
An error wrapping a serialization/deserialization error from the serde_json crate.